@@ -994,7 +994,7 @@ int iscompleteprompt(char *line)
         else
             if (!isspace(*line))
                 ch=*line;
-    return (strchr("?:>.*$#]&)",ch) && !((c==-1)?0:c&0x70));
+    return strchr("?:>.*$#]&)",ch) && !((c==-1)?0:c&0x70);
 }
 
 
