@@ -40,11 +40,6 @@ extern char *prof_area;
 int init_mccp(struct session *ses, int cplen, char *cpsrc);
 #endif
 
-#ifndef SOL_IP
-static int SOL_IP;
-static int SOL_TCP;
-#endif
-
 static int abort_connect;
 
 #ifdef HAVE_GETADDRINFO
@@ -110,10 +105,17 @@ int connect_mud(char *host, char *port, struct session *ses)
         }
 
         val=IPTOS_LOWDELAY;
-        if (setsockopt(sock, SOL_IP, IP_TOS, &val, sizeof(val)))
+        if (setsockopt(sock, IPPROTO_IP, IP_TOS, &val, sizeof(val)))
             /*tintin_eprintf(ses, "#setsockopt: %s", strerror(errno))*/;
             /* FIXME: BSD doesn't like this on IPv6 */
 
+        val=1;
+        setsockopt(sock, SOL_SOCKET, SO_KEEPALIVE, &val, sizeof(val));
+#ifdef TCP_KEEPIDLE
+        val=5*60; /* 5 minutes */
+        setsockopt(sock, IPPROTO_TCP, TCP_KEEPIDLE, &val, sizeof(val));
+#endif
+
         abort_connect=0;
         alarm(15);
     intr:
@@ -182,7 +184,7 @@ int connect_mud(char *host, char *port, struct session *ses)
     sockaddr.sin_family = AF_INET;
 
     val=IPTOS_LOWDELAY;
-    setsockopt(sock, SOL_IP, IP_TOS, &val, sizeof(val));
+    setsockopt(sock, IPPROTO_IP, IP_TOS, &val, sizeof(val));
 
     tintin_printf(ses, "#Trying to connect...");
 
@@ -238,7 +240,7 @@ void write_line_mud(char *line, struct session *ses)
     {
         if (!ses->nagle)
         {
-            setsockopt(ses->socket, SOL_TCP, TCP_NODELAY, &ses->nagle,
+            setsockopt(ses->socket, IPPROTO_TCP, TCP_NODELAY, &ses->nagle,
                 sizeof(ses->nagle));
             ses->nagle=1;
         }
@@ -261,7 +263,7 @@ void write_line_mud(char *line, struct session *ses)
 
 void flush_socket(struct session *ses)
 {
-    setsockopt(ses->socket, SOL_TCP, TCP_NODELAY, &ses->nagle,
+    setsockopt(ses->socket, IPPROTO_TCP, TCP_NODELAY, &ses->nagle,
         sizeof(ses->nagle));
     ses->nagle=0;
 }
@@ -452,17 +454,6 @@ int read_buffer_mud(char *buffer, struct session *ses)
     return didget;
 }
 
-void init_net()
-{
-#ifndef SOL_IP
-    struct protoent *pent;
-    pent = getprotobyname ("ip");
-    SOL_IP = (pent != NULL) ? pent->p_proto : 0;
-    pent = getprotobyname ("tcp");
-    SOL_TCP = (pent != NULL) ? pent->p_proto : 0;
-#endif
-}
-
 #ifdef HAVE_ZLIB
 int init_mccp(struct session *ses, int cplen, char *cpsrc)
 {
